@@ -94,7 +94,6 @@ sub validate {
             $self->explain(
             ">>'$key' is an array reference so we check all elements\n");
             push @{$self->{parent_keys}}, $key;
-            $self->{depth}++;
             for my $member (@{$self->{data}->{$key}}){
                 my $e = Data::Processor::Validator->new(
                     $self->{schema}->{$schema_key}->{members},
@@ -107,7 +106,6 @@ sub validate {
 
             }
             pop @{$self->{parent_keys}};
-            $self->{depth}--;
         }
         # Make sure that key in data is a leaf in schema.
         # We cannot descend into a non-existing branch in data
